#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_LDEXPMASK_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_LDEXPMASK_HPP_INCLUDED

#include <boost/simd/constant/include/constants/ldexpmask.hpp>

#endif
